@@ -1,5 +1,5 @@
 /*
- * $Id: fcgi.h,v 1.44 2003/02/03 23:07:37 robs Exp $
+ * $Id: fcgi.h,v 1.47 2007/09/23 16:33:29 robs Exp $
  */
 
 #ifndef FCGI_H
@@ -73,6 +73,36 @@ typedef apr_status_t apcb_t;
 #define ap_reset_timeout(a)
 #define ap_unblock_alarms()
 
+/* starting with apache 2.2 the backward-compatibility defines for
+ * 1.3 APIs are not available anymore. Define them ourselves here.
+ */
+#ifndef ap_copy_table
+
+#define ap_copy_table apr_table_copy
+#define ap_cpystrn apr_cpystrn
+#define ap_destroy_pool apr_pool_destroy
+#define ap_isspace apr_isspace
+#define ap_make_array apr_array_make
+#define ap_make_table apr_table_make
+#define ap_null_cleanup apr_pool_cleanup_null
+#define ap_palloc apr_palloc
+#define ap_pcalloc apr_pcalloc
+#define ap_psprintf apr_psprintf
+#define ap_pstrcat apr_pstrcat
+#define ap_pstrdup apr_pstrdup
+#define ap_pstrndup apr_pstrndup
+#define ap_push_array apr_array_push
+#define ap_register_cleanup apr_pool_cleanup_register
+#define ap_snprintf apr_snprintf
+#define ap_table_add apr_table_add
+#define ap_table_do apr_table_do
+#define ap_table_get apr_table_get
+#define ap_table_set apr_table_set
+#define ap_table_setn apr_table_setn
+#define ap_table_unset apr_table_unset
+
+#endif /* defined(ap_copy_table) */
+
 #if (defined(HAVE_WRITEV) && !HAVE_WRITEV && !defined(NO_WRITEV)) || defined WIN32
 #define NO_WRITEV
 #endif
@@ -181,6 +211,8 @@ typedef struct _FastCgiServerInfo {
                                      * starting of AppClass processes at init */
     u_int restartDelay;             /* number of seconds to wait between
                                      * restarts after failure.  Can be zero. */
+    u_int minServerLife;            /* minimum number of seconds a server must
+                                     * live before it's considered borked. */
     int restartOnExit;              /* = TRUE = restart. else terminate/free */
     u_int numFailures;              /* num restarts due to exit failure */
     int bad;                        /* is [not] having start problems */
@@ -228,6 +260,7 @@ typedef struct _FastCgiServerInfo {
     u_long totalQueueTime;          /* microseconds spent by the web server
                                      * waiting to connect to the fastcgi app
                                      * since the last dynamicUpdateInterval. */
+    int nph;
     struct _FastCgiServerInfo *next;
 } fcgi_server;
 
@@ -278,6 +311,7 @@ typedef struct {
 #ifdef WIN32
     BOOL using_npipe_io;             /* named pipe io */
 #endif
+    int nph;
 } fcgi_request;
 
 /* Values of parseHeader field */
@@ -582,8 +616,10 @@ extern u_int dynamicInitStartDelay;
 extern u_int dynamicRestartDelay;
 extern array_header *dynamic_pass_headers;
 extern u_int dynamic_idle_timeout;
+extern int dynamicMinServerLife;
 extern int dynamicFlush;
 
+
 extern module MODULE_VAR_EXPORT fastcgi_module;
 
 #endif  /* FCGI_H */
